@@ -18,9 +18,9 @@ bprobNP <- function(params, dat, dat1, dat2, dat1p, dat2p, X1.d2, X2.d2, S=NULL,
   eta2 <- dat2(u)%*%params[(X1.d2+K+1):(X1.d2+X2.d2+2*K)]
 
   A   <- pnorm( (eta2-corr*eta1)*d.r )
-  A.c <- pnorm( (eta2-corr*eta1)*d.r , lower.tail = FALSE)
+  A.c <- 1 - A
   B   <- pnorm( (eta1-corr*eta2)*d.r )
-  B.c <- pnorm( (eta1-corr*eta2)*d.r , lower.tail = FALSE)
+  B.c <- 1 - B
 
   p11 <- pmax( pnorm2( eta1, eta2, corr), 1000*.Machine$double.eps )
   p10 <- pmax( pnorm(eta1) - p11, 1000*.Machine$double.eps )
@@ -54,16 +54,16 @@ bprobNP <- function(params, dat, dat1, dat2, dat1p, dat2p, X1.d2, X2.d2, S=NULL,
 
   be1.be1 <- be2.be2 <- be1.be2 <- be1.rho <- be2.rho <- rho.rho <- g1 <- g2 <- g3 <- 0 
   
-  for (w in 1:K){  
-  g1 <- g1 - colSums( c(dl.dbe1[,w])*We[,w]*dat1(w) )
-  g2 <- g2 - colSums( c(dl.dbe2[,w])*We[,w]*dat2(w) )
-  g3 <- g3 - sum( c(dl.drho[,w])*We[,w] )
-  be1.be1 <- be1.be1 + crossprod(dat1(w)*c(d2l.be1.be1[,w])*We[,w],dat1(w))
-  be2.be2 <- be2.be2 + crossprod(dat2(w)*c(d2l.be2.be2[,w])*We[,w],dat2(w))
-  be1.be2 <- be1.be2 + crossprod(dat1(w)*c(d2l.be1.be2[,w])*We[,w],dat2(w))
-  be1.rho <- be1.rho + t(t(rowSums(t(dat1(w)*c(d2l.be1.rho[,w])*We[,w]))))
-  be2.rho <- be2.rho + t(t(rowSums(t(dat2(w)*c(d2l.be2.rho[,w])*We[,w]))))
-  rho.rho <- rho.rho + c(d2l.rho.rho[,w])*We[,w] 
+  for (u in 1:K){  
+  g1 <- g1 - colSums( c(dl.dbe1[,u])*We[,u]*dat1(u) )
+  g2 <- g2 - colSums( c(dl.dbe2[,u])*We[,u]*dat2(u) )
+  g3 <- g3 - sum( c(dl.drho[,u])*We[,u] )
+  be1.be1 <- be1.be1 + crossprod(dat1(u)*c(d2l.be1.be1[,u])*We[,u],dat1(u))
+  be2.be2 <- be2.be2 + crossprod(dat2(u)*c(d2l.be2.be2[,u])*We[,u],dat2(u))
+  be1.be2 <- be1.be2 + crossprod(dat1(u)*c(d2l.be1.be2[,u])*We[,u],dat2(u))
+  be1.rho <- be1.rho + t(t(rowSums(t(dat1(u)*c(d2l.be1.rho[,u])*We[,u]))))
+  be2.rho <- be2.rho + t(t(rowSums(t(dat2(u)*c(d2l.be2.rho[,u])*We[,u]))))
+  rho.rho <- rho.rho + c(d2l.rho.rho[,u])*We[,u] 
   }
     
   H <- rbind( cbind( be1.be1    , be1.be2    , be1.rho ),
